.. _arq: https://arq-docs.helpmanual.io
.. _asyncpg: https://magicstack.github.io/asyncpg/current/
.. _Click: https://click.palletsprojects.com/
.. _cryptography: https://cryptography.io/en/latest/
.. _FastAPI: https://fastapi.tiangolo.com/
.. _fastapi_safir_app: https://github.com/lsst/templates/tree/main/project_templates/fastapi_safir_app
.. _Gafaelfawr: https://gafaelfawr.lsst.io/
.. _Gidgethub: https://gidgethub.readthedocs.io/en/latest/
.. _HTTPX: https://www.python-httpx.org/
.. _kubernetes_asyncio: https://github.com/tomplus/kubernetes_asyncio
.. _mypy: https://www.mypy-lang.org
.. _Phalanx: https://phalanx.lsst.io
.. _pre-commit: https://pre-commit.com
.. _Pydantic: https://docs.pydantic.dev/latest/
.. _PyPI: https://pypi.org/project/safir/
.. _pytest: https://docs.pytest.org/en/latest/
.. _redis-py: https://redis.readthedocs.io/en/stable/
.. _respx: https://lundberg.github.io/respx/
.. _Roundtable: https://roundtable.lsst.io
.. _scriv: https://scriv.readthedocs.io/en/stable/
.. _semver: https://semver.org/
.. _SQLAlchemy: https://www.sqlalchemy.org/
.. _structlog: https://www.structlog.org/en/stable/
.. _templatekit: https://templatekit.lsst.io
.. _tox: https://tox.wiki/en/latest/
.. _Uvicorn: https://www.uvicorn.org/
